==> ideaIC-143.747.6-sources.jar: com/android/tools/idea/ui/properties/swing/EditableProperty.java <==
/*
 * Copyright (C) 2015 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.android.tools.idea.ui.properties.swing;

import com.android.tools.idea.ui.properties.ObservableProperty;
import com.android.tools.idea.ui.properties.core.BoolProperty;
import org.jetbrains.annotations.NotNull;

import javax.swing.text.JTextComponent;
import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;

/**
 * {@link ObservableProperty} that wraps a Swing component and exposes its editable state.
 */
public final class EditableProperty extends BoolProperty implements PropertyChangeListener {
  private final JTextComponent myTextComponent;

  public EditableProperty(JTextComponent textComponent) {
    myTextComponent = textComponent;
    myTextComponent.addPropertyChangeListener("editable", this);
  }

  @Override
  public void propertyChange(PropertyChangeEvent propertyChangeEvent) {
    notifyInvalidated();
  }

  @NotNull
  @Override
  public Boolean get() {
    return myTextComponent.isEditable();
  }

  @Override
  protected void setDirectly(@NotNull Boolean value) {
    myTextComponent.setEditable(value);
  }
}

==> ideaIC-163.4396.1-sources.jar: com/android/tools/idea/ui/properties/swing/EditableProperty.java <==
/*
 * Copyright (C) 2015 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.android.tools.idea.ui.properties.swing;

import com.android.tools.idea.ui.properties.ObservableProperty;
import com.android.tools.idea.ui.properties.core.BoolProperty;
import org.jetbrains.annotations.NotNull;

import javax.swing.text.JTextComponent;
import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;

/**
 * {@link ObservableProperty} that wraps a Swing component and exposes its editable state.
 */
public final class EditableProperty extends BoolProperty implements PropertyChangeListener {
  @NotNull private final JTextComponent myTextComponent;

  public EditableProperty(@NotNull JTextComponent textComponent) {
    myTextComponent = textComponent;
    myTextComponent.addPropertyChangeListener("editable", this);
  }

  @Override
  public void propertyChange(PropertyChangeEvent propertyChangeEvent) {
    notifyInvalidated();
  }

  @NotNull
  @Override
  public Boolean get() {
    return myTextComponent.isEditable();
  }

  @Override
  protected void setDirectly(@NotNull Boolean value) {
    myTextComponent.setEditable(value);
  }
}
